@@ -1,6 +1,6 @@
 //===----------------------------------------------------------------------===//
 //
-// Copyright (c) 2016 The University of Utah
+// Copyright (c) 2016, 2017, 2018, 2019 The University of Utah
 // All rights reserved.
 //
 // This file is distributed under the University of Illinois Open Source
@@ -23,7 +23,6 @@
 #include "TransformationManager.h"
 
 using namespace clang;
-using namespace llvm;
 
 static const char *DescriptionMsg =
 "Insert a printf statement to print out the value of an expression. \
@@ -60,11 +59,13 @@ public:
     : SrcManager(M), HeaderName(Name), HasHeader(H), HeaderLoc(Loc)
   { }
 
-  void InclusionDirective(SourceLocation HashLoc, const Token &IncludeTok,
+  virtual void InclusionDirective(SourceLocation HashLoc,
+                          const Token &IncludeTok,
                           StringRef FileName, bool IsAngled,
                           CharSourceRange FilenameRange, const FileEntry *File,
                           StringRef SearchPath, StringRef RelativePath,
-                          const Module *Imported) override;
+                          const Module *Imported,
+                          SrcMgr::CharacteristicKind FileType) override;
 
 private:
   SourceManager &SrcManager;
@@ -77,14 +78,15 @@ private:
 };
 
 void IncludesPPCallbacks::InclusionDirective(SourceLocation HashLoc,
-                                            const Token &/*IncludeTok*/,
-                                            StringRef FileName,
+                                             const Token &/*IncludeTok*/,
+                                             StringRef FileName,
                                             bool /*IsAngled*/,
-                                            CharSourceRange /*FilenameRange*/,
-                                            const FileEntry * /*File*/,
-                                            StringRef /*SearchPath*/,
-                                            StringRef /*RelativePath*/,
-                                            const Module * /*Imported*/)
+                                             CharSourceRange /*FilenameRange*/,
+                                             const FileEntry * /*File*/,
+                                             StringRef /*SearchPath*/,
+                                             StringRef /*RelativePath*/,
+                                             const Module * /*Imported*/,
+                                             SrcMgr::CharacteristicKind /*FileType*/)
 {
   if (!SrcManager.isInMainFile(HashLoc))
     return;
@@ -126,7 +128,7 @@ bool LocalTmpVarCollector::VisitDeclRefExpr(DeclRefExpr *DRE)
 // (2) the LHS of a binary operator;
 class LocalUOBOVisitor : public RecursiveASTVisitor<LocalUOBOVisitor> {
 public:
-  explicit LocalUOBOVisitor(SmallPtrSet<const Expr *, 10> &ES)
+  explicit LocalUOBOVisitor(llvm::SmallPtrSet<const Expr *, 10> &ES)
     : InvalidExprs(ES)
   { }
 
@@ -135,7 +137,7 @@ public:
   bool VisitBinaryOperator(BinaryOperator *BO);
 
 private:
-  SmallPtrSet<const Expr *, 10> &InvalidExprs;
+  llvm::SmallPtrSet<const Expr *, 10> &InvalidExprs;
 };
 
 bool LocalUOBOVisitor::VisitUnaryOperator(UnaryOperator *UO)
@@ -575,7 +577,7 @@ bool ExpressionDetector::isValidExpr(Stmt *S, const Expr *E)
   // statement many times. Gain a log of performance improvement.
   auto EI = InvalidExprsInUOBO.find(S);
   if (EI == InvalidExprsInUOBO.end()) {
-    SmallPtrSet<const Expr *, 10> InvalidExprs;
+    llvm::SmallPtrSet<const Expr *, 10> InvalidExprs;
     LocalUOBOVisitor UOBOVisitor(InvalidExprs);
     UOBOVisitor.TraverseStmt(S);
     InvalidExprsInUOBO[S] = InvalidExprs;
