@@ -1,6 +1,6 @@
 //===----------------------------------------------------------------------===//
 //
-// Copyright (c) 2012, 2013, 2014, 2015, 2016 The University of Utah
+// Copyright (c) 2012, 2013, 2014, 2015, 2016, 2017, 2019 The University of Utah
 // All rights reserved.
 //
 // This file is distributed under the University of Illinois Open Source
@@ -24,7 +24,6 @@
 #include "CommonStatementVisitor.h"
 
 using namespace clang;
-using namespace llvm;
 
 static const char *DescriptionMsg =
 "A really simple inliner. \
@@ -70,6 +69,8 @@ public:
 
   bool TraverseConstructorInitializer(CXXCtorInitializer *Init);
 
+  bool TraverseParmVarDecl(ParmVarDecl *PV);
+
   unsigned int getNumStmts(void) {
     return NumStmts;
   }
@@ -187,6 +188,11 @@ bool SimpleInlinerCollectionVisitor::TraverseConstructorInitializer(
   return true;
 }
 
+bool SimpleInlinerCollectionVisitor::TraverseParmVarDecl(ParmVarDecl *PV)
+{
+  return true;
+}
+
 bool SimpleInlinerFunctionVisitor::VisitReturnStmt(ReturnStmt *RS)
 {
   ConsumerInstance->ReturnStmts.push_back(RS);
